==> apache-trafficcontrol-7.0.1.tar.gz: apache-trafficcontrol-7.0.1/traffic_portal/app/src/common/modules/table/deliveryServiceRegexes/TableDeliveryServiceRegexesController.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

var TableDeliveryServiceRegexesController = function(deliveryService, regexes, $scope, $state, locationUtils) {

	$scope.deliveryService = deliveryService;

	$scope.regexes = regexes;

	$scope.editRegex = function(dsId, regexId) {
		locationUtils.navigateToPath('/delivery-services/' + dsId + '/regexes/' + regexId);
	};

	$scope.createRegex = function(dsId) {
		locationUtils.navigateToPath('/delivery-services/' + dsId + '/regexes/new');
	};

	$scope.refresh = function() {
		$state.reload(); // reloads all the resolves for the view
	};

	$scope.navigateToPath = locationUtils.navigateToPath;

	angular.element(document).ready(function () {
		$('#regexesTable').dataTable({
			"aLengthMenu": [[25, 50, 100, -1], [25, 50, 100, "All"]],
			"iDisplayLength": 25,
			"aaSorting": []
		});
	});

};

TableDeliveryServiceRegexesController.$inject = ['deliveryService', 'regexes', '$scope', '$state', 'locationUtils'];
module.exports = TableDeliveryServiceRegexesController;

==> apache-trafficcontrol-8.0.1.tar.gz: apache-trafficcontrol-8.0.1/traffic_portal/app/src/common/modules/table/deliveryServiceRegexes/TableDeliveryServiceRegexesController.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/**
 * @param {*} deliveryService
 * @param {*} regexes
 * @param {*} $scope
 * @param {*} $state
 * @param {import("../../../service/utils/LocationUtils")} locationUtils
 */
var TableDeliveryServiceRegexesController = function(deliveryService, regexes, $scope, $state, locationUtils) {

	$scope.deliveryService = deliveryService;

	$scope.regexes = regexes;

	$scope.editRegex = function(dsId, regexId) {
		locationUtils.navigateToPath('/delivery-services/' + dsId + '/regexes/' + regexId);
	};

	$scope.createRegex = function(dsId) {
		locationUtils.navigateToPath('/delivery-services/' + dsId + '/regexes/new');
	};

	$scope.refresh = function() {
		$state.reload(); // reloads all the resolves for the view
	};

	$scope.navigateToPath = (path, unsavedChanges) => locationUtils.navigateToPath(path, unsavedChanges);

	angular.element(document).ready(function () {
		$('#regexesTable').dataTable({
			"aLengthMenu": [[25, 50, 100, -1], [25, 50, 100, "All"]],
			"iDisplayLength": 25,
			"aaSorting": []
		});
	});

};

TableDeliveryServiceRegexesController.$inject = ['deliveryService', 'regexes', '$scope', '$state', 'locationUtils'];
module.exports = TableDeliveryServiceRegexesController;
